@@ -1,31 +1,29 @@
 /*
- * "$Id: ppd.h 7791 2008-07-24 00:55:30Z mike $"
+ * PostScript Printer Description definitions for CUPS.
  *
- *   PostScript Printer Description definitions for CUPS.
+ * THESE APIS ARE DEPRECATED. TO COMPILE WITHOUT WARNINGS ADD
+ * -D_PPD_DEPRECATED="" TO YOUR COMPILE OPTIONS.  THIS HEADER AND THESE
+ * FUNCTIONS WILL BE REMOVED IN A FUTURE RELEASE OF CUPS.
  *
- *   THESE APIS ARE DEPRECATED. TO COMPILE WITHOUT WARNINGS ADD
- *   -D_PPD_DEPRECATED="" TO YOUR COMPILE OPTIONS.  THIS HEADER AND THESE
- *   FUNCTIONS WILL BE REMOVED IN A FUTURE RELEASE OF CUPS.
+ * Copyright © 2007-2019 by Apple Inc.
+ * Copyright © 1997-2007 by Easy Software Products, all rights reserved.
  *
- *   Copyright 2007-2012 by Apple Inc.
- *   Copyright 1997-2007 by Easy Software Products, all rights reserved.
+ * These coded instructions, statements, and computer programs are the
+ * property of Apple Inc. and are protected by Federal copyright
+ * law.  Distribution and use rights are outlined in the file "LICENSE.txt"
+ * which should have been included with this file.  If this file is
+ * missing or damaged, see the license at "http://www.cups.org/".
  *
- *   These coded instructions, statements, and computer programs are the
- *   property of Apple Inc. and are protected by Federal copyright
- *   law.  Distribution and use rights are outlined in the file "LICENSE.txt"
- *   which should have been included with this file.  If this file is
- *   file is missing or damaged, see the license at "http://www.cups.org/".
+ * PostScript is a trademark of Adobe Systems, Inc.
  *
- *   PostScript is a trademark of Adobe Systems, Inc.
+ * This code and any derivative of it may be used and distributed
+ * freely under the terms of the GNU General Public License when
+ * used with GNU Ghostscript or its derivatives.  Use of the code
+ * (or any derivative of it) with software other than GNU
+ * GhostScript (or its derivatives) is governed by the CUPS license
+ * agreement.
  *
- *   This code and any derivative of it may be used and distributed
- *   freely under the terms of the GNU General Public License when
- *   used with GNU Ghostscript or its derivatives.  Use of the code
- *   (or any derivative of it) with software other than GNU
- *   GhostScript (or its derivatives) is governed by the CUPS license
- *   agreement.
- *
- *   This file is subject to the Apple OS-Developed Software exception.
+ * This file is subject to the Apple OS-Developed Software exception.
  */
 
 #ifndef _CUPS_PPD_H_
@@ -39,6 +37,7 @@
 #  include "cups.h"
 #  include "array.h"
 #  include "file.h"
+#  include "raster.h"
 
 
 /*
@@ -56,19 +55,7 @@ extern "C" {
  */
 
 #  ifndef _PPD_DEPRECATED
-#    if defined(__APPLE__)
-#      if defined(MAC_OS_X_VERSION_10_8) && MAC_OS_X_VERSION_MIN_REQUIRED < MAC_OS_X_VERSION_10_8
-         /* Building for OS X 10.7 and earlier */
-#        define _PPD_DEPRECATED
-#      elif !defined(MAC_OS_X_VERSION_10_8)
-	 /* Building for OS X 10.7 and earlier */
-#        define _PPD_DEPRECATED
-#      else
-#        define _PPD_DEPRECATED _CUPS_DEPRECATED
-#      endif /* MAC_OS_X_VERSION_10_8 && MAC_OS_X_VERSION_MIN_REQUIRED < MAC_OS_X_VERSION_10_8 */
-#    else
-#      define _PPD_DEPRECATED _CUPS_DEPRECATED
-#    endif /* __APPLE__ */
+#    define _PPD_DEPRECATED _CUPS_DEPRECATED_1_6_MSG("Use cupsCopyDestInfo and friends instead.")
 #  endif /* !_PPD_DEPRECATED */
 
 
@@ -119,7 +106,7 @@ typedef enum ppd_cs_e			/**** Colorspaces ****/
   PPD_CS_N				/* DeviceN colorspace */
 } ppd_cs_t;
 
-typedef enum ppd_status_e		/**** Status Codes @since CUPS 1.1.19/OS X 10.3@ ****/
+typedef enum ppd_status_e		/**** Status Codes @since CUPS 1.1.19/macOS 10.3@ ****/
 {
   PPD_OK = 0,				/* OK */
   PPD_FILE_OPEN_ERROR,			/* Unable to open PPD file */
@@ -145,19 +132,21 @@ typedef enum ppd_status_e		/**** Status Codes @since CUPS 1.1.19/OS X 10.3@ ****
   PPD_MISSING_OPTION_KEYWORD,		/* Missing option keyword */
   PPD_BAD_VALUE,			/* Bad value string */
   PPD_MISSING_CLOSE_GROUP,		/* Missing CloseGroup */
+  PPD_BAD_CLOSE_UI,			/* Bad CloseUI/JCLCloseUI */
+  PPD_MISSING_CLOSE_UI,			/* Missing CloseUI/JCLCloseUI */
   PPD_MAX_STATUS			/* @private@ */
 } ppd_status_t;
 
-enum ppd_conform_e			/**** Conformance Levels @since CUPS 1.1.19/OS X 10.3@ ****/
+enum ppd_conform_e			/**** Conformance Levels @since CUPS 1.1.19/macOS 10.3@ ****/
 {
   PPD_CONFORM_RELAXED,			/* Relax whitespace and control char */
   PPD_CONFORM_STRICT			/* Require strict conformance */
 };
 
 typedef enum ppd_conform_e ppd_conform_t;
-					/**** Conformance Levels @since CUPS 1.1.19/OS X 10.3@ ****/
+					/**** Conformance Levels @since CUPS 1.1.19/macOS 10.3@ ****/
 
-typedef struct ppd_attr_s		/**** PPD Attribute Structure @since CUPS 1.1.19/OS X 10.3@ ****/
+typedef struct ppd_attr_s		/**** PPD Attribute Structure @since CUPS 1.1.19/macOS 10.3@ ****/
 {
   char		name[PPD_MAX_NAME];	/* Name of attribute (cupsXYZ) */
   char		spec[PPD_MAX_NAME];	/* Specifier string, if any */
@@ -198,7 +187,7 @@ typedef struct ppd_group_s		/**** Groups ****/
    ****/
   char		text[PPD_MAX_TEXT - PPD_MAX_NAME];
   					/* Human-readable group name */
-  char		name[PPD_MAX_NAME];	/* Group name @since CUPS 1.1.18/OS X 10.3@ */
+  char		name[PPD_MAX_NAME];	/* Group name @since CUPS 1.1.18/macOS 10.3@ */
   int		num_options;		/* Number of options */
   ppd_option_t	*options;		/* Options */
   int		num_subgroups;		/* Number of sub-groups */
@@ -243,8 +232,8 @@ typedef struct ppd_profile_s		/**** sRGB Color Profiles ****/
   float		matrix[3][3];		/* Transform matrix */
 } ppd_profile_t;
 
-/**** New in CUPS 1.2/OS X 10.5 ****/
-typedef enum ppd_cptype_e		/**** Custom Parameter Type @since CUPS 1.2/OS X 10.5@ ****/
+/**** New in CUPS 1.2/macOS 10.5 ****/
+typedef enum ppd_cptype_e		/**** Custom Parameter Type @since CUPS 1.2/macOS 10.5@ ****/
 {
   PPD_CUSTOM_CURVE,			/* Curve value for f(x) = x^value */
   PPD_CUSTOM_INT,			/* Integer number value */
@@ -256,7 +245,7 @@ typedef enum ppd_cptype_e		/**** Custom Parameter Type @since CUPS 1.2/OS X 10.5
   PPD_CUSTOM_STRING			/* String of characters */
 } ppd_cptype_t;
 
-typedef union ppd_cplimit_u		/**** Custom Parameter Limit @since CUPS 1.2/OS X 10.5@ ****/
+typedef union ppd_cplimit_u		/**** Custom Parameter Limit @since CUPS 1.2/macOS 10.5@ ****/
 {
   float		custom_curve;		/* Gamma value */
   int		custom_int;		/* Integer value */
@@ -268,7 +257,7 @@ typedef union ppd_cplimit_u		/**** Custom Parameter Limit @since CUPS 1.2/OS X 1
   int		custom_string;		/* String length */
 } ppd_cplimit_t;
 
-typedef union ppd_cpvalue_u		/**** Custom Parameter Value @since CUPS 1.2/OS X 10.5@ ****/
+typedef union ppd_cpvalue_u		/**** Custom Parameter Value @since CUPS 1.2/macOS 10.5@ ****/
 {
   float		custom_curve;		/* Gamma value */
   int		custom_int;		/* Integer value */
@@ -280,7 +269,7 @@ typedef union ppd_cpvalue_u		/**** Custom Parameter Value @since CUPS 1.2/OS X 1
   char		*custom_string;		/* String value */
 } ppd_cpvalue_t;
 
-typedef struct ppd_cparam_s		/**** Custom Parameter @since CUPS 1.2/OS X 10.5@ ****/
+typedef struct ppd_cparam_s		/**** Custom Parameter @since CUPS 1.2/macOS 10.5@ ****/
 {
   char		name[PPD_MAX_NAME];	/* Parameter name */
   char		text[PPD_MAX_TEXT];	/* Human-readable text */
@@ -291,7 +280,7 @@ typedef struct ppd_cparam_s		/**** Custom Parameter @since CUPS 1.2/OS X 10.5@ *
   ppd_cpvalue_t	current;		/* Current value */
 } ppd_cparam_t;
 
-typedef struct ppd_coption_s		/**** Custom Option @since CUPS 1.2/OS X 10.5@ ****/
+typedef struct ppd_coption_s		/**** Custom Option @since CUPS 1.2/macOS 10.5@ ****/
 {
   char		keyword[PPD_MAX_NAME];	/* Name of option that is being extended... */
   ppd_option_t	*option;		/* Option that is being extended... */
@@ -300,7 +289,7 @@ typedef struct ppd_coption_s		/**** Custom Option @since CUPS 1.2/OS X 10.5@ ***
 } ppd_coption_t;
 
 typedef struct _ppd_cache_s _ppd_cache_t;
-					/**** PPD cache and mapping data @since CUPS 1.5/OS X 10.7@ @private@ ****/
+					/**** PPD cache and mapping data @since CUPS 1.5/macOS 10.7@ @private@ ****/
 
 typedef struct ppd_file_s		/**** PPD File ****/
 {
@@ -315,8 +304,8 @@ typedef struct ppd_file_s		/**** PPD File ****/
   int		throughput;		/* Pages per minute */
   ppd_cs_t	colorspace;		/* Default colorspace */
   char		*patches;		/* Patch commands to be sent to printer */
-  int		num_emulations;		/* Number of emulations supported */
-  ppd_emul_t	*emulations;		/* Emulations and the code to invoke them */
+  int		num_emulations;		/* Number of emulations supported (no longer supported) @private@ */
+  ppd_emul_t	*emulations;		/* Emulations and the code to invoke them (no longer supported) @private@ */
   char		*jcl_begin;		/* Start JCL commands */
   char		*jcl_ps;		/* Enter PostScript interpreter */
   char		*jcl_end;		/* End JCL commands */
@@ -348,25 +337,25 @@ typedef struct ppd_file_s		/**** PPD File ****/
   int		flip_duplex;		/* 1 = Flip page for back sides @deprecated@ */
 
   /**** New in CUPS 1.1.19 ****/
-  char		*protocols;		/* Protocols (BCP, TBCP) string @since CUPS 1.1.19/OS X 10.3@ */
-  char		*pcfilename;		/* PCFileName string @since CUPS 1.1.19/OS X 10.3@ */
-  int		num_attrs;		/* Number of attributes @since CUPS 1.1.19/OS X 10.3@ @private@ */
-  int		cur_attr;		/* Current attribute @since CUPS 1.1.19/OS X 10.3@ @private@ */
-  ppd_attr_t	**attrs;		/* Attributes @since CUPS 1.1.19/OS X 10.3@ @private@ */
+  char		*protocols;		/* Protocols (BCP, TBCP) string @since CUPS 1.1.19/macOS 10.3@ */
+  char		*pcfilename;		/* PCFileName string @since CUPS 1.1.19/macOS 10.3@ */
+  int		num_attrs;		/* Number of attributes @since CUPS 1.1.19/macOS 10.3@ @private@ */
+  int		cur_attr;		/* Current attribute @since CUPS 1.1.19/macOS 10.3@ @private@ */
+  ppd_attr_t	**attrs;		/* Attributes @since CUPS 1.1.19/macOS 10.3@ @private@ */
 
-  /**** New in CUPS 1.2/OS X 10.5 ****/
-  cups_array_t	*sorted_attrs;		/* Attribute lookup array @since CUPS 1.2/OS X 10.5@ @private@ */
-  cups_array_t	*options;		/* Option lookup array @since CUPS 1.2/OS X 10.5@ @private@ */
-  cups_array_t	*coptions;		/* Custom options array @since CUPS 1.2/OS X 10.5@ @private@ */
+  /**** New in CUPS 1.2/macOS 10.5 ****/
+  cups_array_t	*sorted_attrs;		/* Attribute lookup array @since CUPS 1.2/macOS 10.5@ @private@ */
+  cups_array_t	*options;		/* Option lookup array @since CUPS 1.2/macOS 10.5@ @private@ */
+  cups_array_t	*coptions;		/* Custom options array @since CUPS 1.2/macOS 10.5@ @private@ */
 
-  /**** New in CUPS 1.3/OS X 10.5 ****/
-  cups_array_t	*marked;		/* Marked choices @since CUPS 1.3/OS X 10.5@ @private@ */
+  /**** New in CUPS 1.3/macOS 10.5 ****/
+  cups_array_t	*marked;		/* Marked choices @since CUPS 1.3/macOS 10.5@ @private@ */
 
-  /**** New in CUPS 1.4/OS X 10.6 ****/
-  cups_array_t	*cups_uiconstraints;	/* cupsUIConstraints @since CUPS 1.4/OS X 10.6@ @private@ */
+  /**** New in CUPS 1.4/macOS 10.6 ****/
+  cups_array_t	*cups_uiconstraints;	/* cupsUIConstraints @since CUPS 1.4/macOS 10.6@ @private@ */
 
   /**** New in CUPS 1.5 ****/
-  _ppd_cache_t	*cache;			/* PPD cache and mapping data @since CUPS 1.5/OS X 10.7@ @private@ */
+  _ppd_cache_t	*cache;			/* PPD cache and mapping data @since CUPS 1.5/macOS 10.7@ @private@ */
 } ppd_file_t;
 
 
@@ -374,33 +363,44 @@ typedef struct ppd_file_s		/**** PPD File ****/
  * Prototypes...
  */
 
-extern int		cupsMarkOptions(ppd_file_t *ppd, int num_options,
-			                cups_option_t *options);
-extern void		ppdClose(ppd_file_t *ppd);
+extern const char	*cupsGetPPD(const char *name) _PPD_DEPRECATED;
+extern const char	*cupsGetPPD2(http_t *http, const char *name) _PPD_DEPRECATED;
+extern http_status_t	cupsGetPPD3(http_t *http, const char *name, time_t *modtime, char *buffer, size_t bufsize) _PPD_DEPRECATED;
+extern char		*cupsGetServerPPD(http_t *http, const char *name) _PPD_DEPRECATED;
+extern int		cupsMarkOptions(ppd_file_t *ppd, int num_options, cups_option_t *options) _PPD_DEPRECATED;
+
+extern void		ppdClose(ppd_file_t *ppd) _PPD_DEPRECATED;
 extern int		ppdCollect(ppd_file_t *ppd, ppd_section_t section,
-			           ppd_choice_t  ***choices);
-extern int		ppdConflicts(ppd_file_t *ppd);
+			           ppd_choice_t  ***choices) _PPD_DEPRECATED;
+extern int		ppdConflicts(ppd_file_t *ppd) _PPD_DEPRECATED;
 extern int		ppdEmit(ppd_file_t *ppd, FILE *fp,
-			        ppd_section_t section);
+			        ppd_section_t section) _PPD_DEPRECATED;
 extern int		ppdEmitFd(ppd_file_t *ppd, int fd,
-			          ppd_section_t section);
+			          ppd_section_t section) _PPD_DEPRECATED;
 extern int		ppdEmitJCL(ppd_file_t *ppd, FILE *fp, int job_id,
-			           const char *user, const char *title);
-extern ppd_choice_t	*ppdFindChoice(ppd_option_t *o, const char *option);
+			           const char *user, const char *title)
+			           _PPD_DEPRECATED;
+extern ppd_choice_t	*ppdFindChoice(ppd_option_t *o, const char *option)
+			               _PPD_DEPRECATED;
 extern ppd_choice_t	*ppdFindMarkedChoice(ppd_file_t *ppd,
-			                     const char *keyword);
-extern ppd_option_t	*ppdFindOption(ppd_file_t *ppd, const char *keyword);
+			                     const char *keyword)
+			                     _PPD_DEPRECATED;
+extern ppd_option_t	*ppdFindOption(ppd_file_t *ppd, const char *keyword)
+			               _PPD_DEPRECATED;
 extern int		ppdIsMarked(ppd_file_t *ppd, const char *keyword,
-			            const char *option);
-extern void		ppdMarkDefaults(ppd_file_t *ppd);
+			            const char *option) _PPD_DEPRECATED;
+extern void		ppdMarkDefaults(ppd_file_t *ppd) _PPD_DEPRECATED;
 extern int		ppdMarkOption(ppd_file_t *ppd, const char *keyword,
-			              const char *option);
-extern ppd_file_t	*ppdOpen(FILE *fp);
-extern ppd_file_t	*ppdOpenFd(int fd);
-extern ppd_file_t	*ppdOpenFile(const char *filename);
-extern float		ppdPageLength(ppd_file_t *ppd, const char *name);
-extern ppd_size_t	*ppdPageSize(ppd_file_t *ppd, const char *name);
-extern float		ppdPageWidth(ppd_file_t *ppd, const char *name);
+			              const char *option) _PPD_DEPRECATED;
+extern ppd_file_t	*ppdOpen(FILE *fp) _PPD_DEPRECATED;
+extern ppd_file_t	*ppdOpenFd(int fd) _PPD_DEPRECATED;
+extern ppd_file_t	*ppdOpenFile(const char *filename) _PPD_DEPRECATED;
+extern float		ppdPageLength(ppd_file_t *ppd, const char *name)
+			              _PPD_DEPRECATED;
+extern ppd_size_t	*ppdPageSize(ppd_file_t *ppd, const char *name)
+			             _PPD_DEPRECATED;
+extern float		ppdPageWidth(ppd_file_t *ppd, const char *name)
+			             _PPD_DEPRECATED;
 
 /**** New in CUPS 1.1.19 ****/
 extern const char	*ppdErrorString(ppd_status_t status) _PPD_DEPRECATED;
@@ -414,38 +414,46 @@ extern ppd_status_t	ppdLastError(int *line) _PPD_DEPRECATED;
 extern void		ppdSetConformance(ppd_conform_t c) _PPD_DEPRECATED;
 
 /**** New in CUPS 1.2 ****/
+extern int		cupsRasterInterpretPPD(cups_page_header2_t *h,
+			                       ppd_file_t *ppd,
+					       int num_options,
+					       cups_option_t *options,
+					       cups_interpret_cb_t func) _PPD_DEPRECATED;
 extern int		ppdCollect2(ppd_file_t *ppd, ppd_section_t section,
 			            float min_order, ppd_choice_t  ***choices)
 			            _PPD_DEPRECATED;
 extern int		ppdEmitAfterOrder(ppd_file_t *ppd, FILE *fp,
 			                  ppd_section_t section, int limit,
 					  float min_order) _PPD_DEPRECATED;
-extern int		ppdEmitJCLEnd(ppd_file_t *ppd, FILE *fp) _PPD_DEPRECATED;
+extern int		ppdEmitJCLEnd(ppd_file_t *ppd, FILE *fp)
+			              _PPD_DEPRECATED;
 extern char		*ppdEmitString(ppd_file_t *ppd, ppd_section_t section,
 			               float min_order) _PPD_DEPRECATED;
 extern ppd_coption_t	*ppdFindCustomOption(ppd_file_t *ppd,
-			                     const char *keyword) _PPD_DEPRECATED;
+			                     const char *keyword)
+			                     _PPD_DEPRECATED;
 extern ppd_cparam_t	*ppdFindCustomParam(ppd_coption_t *opt,
 			                    const char *name) _PPD_DEPRECATED;
-extern ppd_cparam_t	*ppdFirstCustomParam(ppd_coption_t *opt) _PPD_DEPRECATED;
+extern ppd_cparam_t	*ppdFirstCustomParam(ppd_coption_t *opt)
+			                     _PPD_DEPRECATED;
 extern ppd_option_t	*ppdFirstOption(ppd_file_t *ppd) _PPD_DEPRECATED;
 extern ppd_cparam_t	*ppdNextCustomParam(ppd_coption_t *opt) _PPD_DEPRECATED;
 extern ppd_option_t	*ppdNextOption(ppd_file_t *ppd) _PPD_DEPRECATED;
 extern int		ppdLocalize(ppd_file_t *ppd) _PPD_DEPRECATED;
 extern ppd_file_t	*ppdOpen2(cups_file_t *fp) _PPD_DEPRECATED;
 
-/**** New in CUPS 1.3/OS X 10.5 ****/
+/**** New in CUPS 1.3/macOS 10.5 ****/
 extern const char	*ppdLocalizeIPPReason(ppd_file_t *ppd,
 			                      const char *reason,
 					      const char *scheme,
 					      char *buffer,
 					      size_t bufsize) _PPD_DEPRECATED;
 
-/**** New in CUPS 1.4/OS X 10.6 ****/
+/**** New in CUPS 1.4/macOS 10.6 ****/
 extern int		cupsGetConflicts(ppd_file_t *ppd, const char *option,
 					 const char *choice,
 					 cups_option_t **options)
-					     _PPD_DEPRECATED;
+					 _PPD_DEPRECATED;
 extern int		cupsResolveConflicts(ppd_file_t *ppd,
 			                     const char *option,
 			                     const char *choice,
@@ -455,7 +463,7 @@ extern int		cupsResolveConflicts(ppd_file_t *ppd,
 extern int		ppdInstallableConflict(ppd_file_t *ppd,
 			                       const char *option,
 					       const char *choice)
-					           _PPD_DEPRECATED;
+					       _PPD_DEPRECATED;
 extern ppd_attr_t	*ppdLocalizeAttr(ppd_file_t *ppd, const char *keyword,
 			                 const char *spec) _PPD_DEPRECATED;
 extern const char	*ppdLocalizeMarkerName(ppd_file_t *ppd,
@@ -474,7 +482,3 @@ extern int		ppdPageSizeLimits(ppd_file_t *ppd,
 }
 #  endif /* __cplusplus */
 #endif /* !_CUPS_PPD_H_ */
-
-/*
- * End of "$Id: ppd.h 7791 2008-07-24 00:55:30Z mike $".
- */
